package ru.ldeloff.servermonitorbot.controller;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.telegram.telegrambots.bots.TelegramLongPollingBot;
import org.telegram.telegrambots.meta.api.methods.send.SendMessage;
import org.telegram.telegrambots.meta.api.objects.Update;
import org.telegram.telegrambots.meta.exceptions.TelegramApiException;
import ru.ldeloff.servermonitorbot.model.TelegramBot;
import ru.ldeloff.servermonitorbot.repository.SshRepository;
import ru.ldeloff.servermonitorbot.service.TelegramBotService;
import ru.ldeloff.servermonitorbot.utils.ui.TelegramBotKeyboard;
import ru.ldeloff.servermonitorbot.utils.ui.uname.UnameChatButtonAggregate;

@Service
@Slf4j
@RequiredArgsConstructor
public class TelegramBotController extends TelegramLongPollingBot {

    final TelegramBot telegramBot;
    final SshRepository sshRepository;
    final TelegramBotService telegramBotService;

    @Override
    public void onUpdateReceived(Update update) {
        if (update.hasMessage()) {
            if (update.getMessage().hasText()) {
                String messageText = update.getMessage().getText();
                switch (messageText) {
                    case "/start" -> {
                        log.info("Получена команда '" + messageText
                                + "' от " + update.getMessage().getChat().getUserName());
                        telegramBotService.firstUse(update, this);
                    }
                    case "Статус" -> {
                        log.info("Получена команда '" + messageText
                                + "' от " + update.getMessage().getChat().getUserName());
                        telegramBotService.getStatusSessions(update, this);
                    }
                    case "uname" -> {
                        log.info("Получена команда '" + messageText
                                + "' от " + update.getMessage().getChat().getUserName());
                        telegramBotService.sendUnameAggregate(update, this);
                    }
                    default -> {
                        log.warn("Неизвестная команда '" + messageText
                                + "' от " + update.getMessage().getChat().getUserName());
                        telegramBotService.switchToMainMenu(update, this);
                    }
                }
            }
        } else if (update.hasCallbackQuery()) {
            String messageText = update.getCallbackQuery().getData();
            String [] tags = messageText.split(":");
            if (tags.length > 1) {
                switch (tags[0]) {
                    case "uname":
                        log.info("Получена команда '" + messageText
                                + "' от " + update.getCallbackQuery().getMessage().getChat().getUserName());
                        telegramBotService.uname(update, this);
                        break;
                    default:
                        log.warn("Неизвестная команда '" + messageText
                                + "' от " + update.getCallbackQuery().getMessage().getChat().getUserName());
                        telegramBotService.switchToMainMenu(update, this);
                        break;
                }
            } else {
                    log.warn("Неверный формат команды '" + messageText
                            + "' от " + update.getCallbackQuery().getMessage().getChat().getUserName());
                    telegramBotService.switchToMainMenu(update, this);
            }
        }
    }

    @Override
    public String getBotUsername() {
        return telegramBot.getBotUsername();
    }

    @Override
    public String getBotToken() {
        return telegramBot.getBotToken();
    }

    @Override
    public void onClosing() {
        super.onClosing();
        sshRepository.disconnectSessions();
    }
}
