package ru.ldeloff.servermonitorbot.utils.ui.uname;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.telegram.telegrambots.meta.api.methods.send.SendMessage;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.InlineKeyboardMarkup;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.buttons.InlineKeyboardButton;
import ru.ldeloff.servermonitorbot.repository.SshRepository;
import ru.ldeloff.servermonitorbot.service.ssh.SshService;
import ru.ldeloff.servermonitorbot.utils.ui.UiFormer;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@Component
@RequiredArgsConstructor
public class UnameChatButtonAggregate implements UiFormer {

    private final SshService sshService;

    @Override
    public SendMessage uiForm(SendMessage message) {
        List<List<InlineKeyboardButton>> keyboard = new ArrayList<>();

        InlineKeyboardMarkup inlineKeyboardMarkup = new InlineKeyboardMarkup();

        sshService.getSshServers().forEach(sshServer -> {
            if (Objects.nonNull(sshServer.getSession())) {
                if (sshServer.getSession().isConnected()) {
                    List<InlineKeyboardButton> keyboardRow = new ArrayList<>();
                    InlineKeyboardButton inlineKeyboardButton = new InlineKeyboardButton();
                    inlineKeyboardButton.setText(sshServer.getName());
                    inlineKeyboardButton.setCallbackData("uname: " + sshServer.getName());
                    keyboardRow.add(inlineKeyboardButton);
                    keyboard.add(keyboardRow);
                }
            }
        });

        if (keyboard.size() > 1) {
            List<InlineKeyboardButton> keyboardRow = new ArrayList<>();
            InlineKeyboardButton inlineKeyboardButton = new InlineKeyboardButton();
            inlineKeyboardButton.setText("Все сервера");
            inlineKeyboardButton.setCallbackData("uname: all");
            keyboardRow.add(inlineKeyboardButton);
            keyboard.add(keyboardRow);
        }

        inlineKeyboardMarkup.setKeyboard(keyboard);
        message.setReplyMarkup(inlineKeyboardMarkup);
        message.setText("Выполнить uname для");

        return message;
    }
}
